abacusai.eda — AbacusAI documentation

# `abacusai.eda`

## Module Contents

### Classes

`Eda` | A exploratory data analysis object

class abacusai.eda.Eda(client, edaId=None, name=None, createdAt=None, projectId=None, featureGroupId=None, referenceFeatureGroupVersion=None, testFeatureGroupVersion=None, edaConfigs=None, latestEdaVersion={}, refreshSchedules={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A exploratory data analysis object

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - edaId (str) – The unique identifier of the eda object.

    - name (str) – The user-friendly name for the eda object.

    - createdAt (str) – Date and time at which the eda object was created.

    - projectId (str) – The project this eda object belongs to.

    - featureGroupId (str) – Feature group ID for which eda analysis is being done.

    - referenceFeatureGroupVersion (str) – Reference Feature group version for data consistency analysis, will be latest feature group version for collinearity analysis.

    - testFeatureGroupVersion (str) – Test Feature group version for data consistency analysis, will be latest feature group version for collinearity analysis.

    - edaConfigs (dict) – Configurations for eda object.

    - latestEdaVersion (EdaVersion) – The latest eda object version.

    - refreshSchedules (RefreshSchedule) – List of refresh schedules that indicate when the next model version will be trained.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  rerun()

    Reruns the specified EDA object.

    Parameters:

      eda_id (str) – Unique string identifier of the EDA object to rerun.

    Returns:

      The EDA object that is being rerun.

    Return type:

      Eda

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      Eda

  describe()

    Retrieves a full description of the specified EDA object.

    Parameters:

      eda_id (str) – Unique string identifier associated with the EDA object.

    Returns:

      Description of the EDA object.

    Return type:

      Eda

  list_versions(limit=100, start_after_version=None)

    Retrieves a list of versions for a given EDA object.

    Parameters:

      - limit (int) – The maximum length of the list of all EDA versions.

      - start_after_version (str) – The ID of the version after which the list starts.

    Returns:

      A list of EDA versions.

    Return type:

      EdaVersion

  rename(name)

    Renames an EDA

    Parameters:

      name (str) – The new name to apply to the model monitor.

  delete()

    Deletes the specified EDA and all its versions.

    Parameters:

      eda_id (str) – Unique string identifier of the EDA to delete.